<?php

namespace Lc\CaracoleBundle\Repository\User;

use Doctrine\ORM\EntityManagerInterface;
use Lc\CaracoleBundle\Repository\AbstractStore;
use Lc\SovBundle\Repository\RepositoryQueryInterface;

class VisitorStore extends AbstractStore
{
    protected VisitorRepositoryQuery $query;

    public function __construct(
        VisitorRepositoryQuery $query,
        EntityManagerInterface $entityManager
    )
    {
        $this->entityManager = $entityManager;
        $this->query = $query;
    }

    public function orderByDefault(RepositoryQueryInterface $query): RepositoryQueryInterface
    {
        $query->orderBy('id');
        return $query;
    }

    public function filtersDefault(RepositoryQueryInterface $query): RepositoryQueryInterface
    {
        return $query;
    }

    public function relationsDefault(RepositoryQueryInterface $query): RepositoryQueryInterface
    {
        return $query;
    }

    public function getOneByCookie(string $cookie = null, $query = null)
    {
        $query = $this->createDefaultQuery($query);
        $query->filterByCookie($cookie);
        return $query->findOne();
    }

    public function getOldVisitorsWithoutOrder(\DateTime $lastAccess, $query = null)
    {

        $sql = 'SELECT visitor.* FROM visitor LEFT JOIN order_shop ON order_shop.visitor_id = visitor.id';
        $sql .= ' WHERE visitor.last_access < :last_access AND visitor.total_visit = 1 ';
        $sql .= ' AND order_shop.id is NULL';
        $sql .= '  LIMIT 1000';

        $conn = $this->entityManager->getConnection();
        $stmt = $conn->prepare($sql);

        $paramExecute = [
            'last_access' => $lastAccess->format('Y-m-d H:i:s'),
        ];

        $resultQuery = $stmt->executeQuery($paramExecute);

        return $resultQuery->fetchAllAssociative();

        //ANCIENNE METHODE
//        $query = $this->createDefaultQuery($query);
//        $query->filterByLastAccess($lastAccess);
//        $query->filterByTotalVisit(1);
//        return $query->limit(1000)->find();
    }
}
